@@ -1,6 +1,14 @@
 from django.conf.urls.defaults import *
+from django.contrib.syndication.views import feed
 from django.views.generic import date_based, list_detail
 from articles import views
+from articles.feeds import TagFeed, LatestEntries
+
+feeds = {
+  'latest': LatestEntries,
+  'tags': TagFeed
+}
+feed_dict = {'feed_dict': feeds}
 
 urlpatterns = patterns('',
     (r'^(?P<year>\d{4})/(?P<month>.{3})/(?P<day>\d{1,2})/(?P<slug>.*)/$', views.redirect_to_article),
@@ -15,8 +23,6 @@ urlpatterns += patterns('',
     url(r'^tag/(?P<tag>.*)/page/(?P<page>\d+)/$', views.display_blog_page, name='articles_display_tag_page'),
     url(r'^tag/(?P<tag>.*)/$', views.display_blog_page, name='articles_display_tag'),
 
-    url(r'^category/(?P<tag>.*)/$', 'django.views.generic.simple.redirect_to', {'url': '../../tag/%(tag)s'}),
-
     url(r'^author/(?P<username>.*)/page/(?P<page>\d+)/$', views.display_blog_page, name='articles_by_author_page'),
     url(r'^author/(?P<username>.*)/$', views.display_blog_page, name='articles_by_author'),
 
@@ -24,4 +30,9 @@ urlpatterns += patterns('',
 
     # AJAX
     url(r'^ajax/tag/autocomplete/$', views.ajax_tag_autocomplete, name='articles_tag_autocomplete'),
+
+    # RSS
+    (r'^feeds/(?P<url>.*)/$', feed, feed_dict),
+    url(r'^feeds/(?P<url>.*)\.rss$', feed, feed_dict, name='articles_feed'),
+
 )
